@@ -5,8 +5,20 @@ from prospector.tools import ToolBase
 
 __all__ = ("MypyTool",)
 
+from prospector.tools.exceptions import BadToolConfig
 
-MYPY_OPTIONS = ["allow", "check", "disallow", "no-check", "no-warn", "warn"]
+LIST_OPTIONS = ["allow", "check", "disallow", "no-check", "no-warn", "warn"]
+VALID_OPTIONS = LIST_OPTIONS + [
+    "strict",
+    "follow-imports",
+    "ignore-missing-imports",
+    "implicit-optional",
+    "strict-optional",
+    "platform",
+    "python-2-mode",
+    "python-version",
+    "namespace-packages",
+]
 
 
 def format_message(message):
@@ -47,6 +59,13 @@ class MypyTool(ToolBase):
     def configure(self, prospector_config, _):
         options = prospector_config.tool_options("mypy")
 
+        for option_key in options.keys():
+            if option_key not in VALID_OPTIONS:
+                url = "https://github.com/PyCQA/prospector/blob/master/prospector/tools/mypy/__init__.py"
+                raise BadToolConfig(
+                    "mypy", f"Option {option_key} is not valid. " f"See the list of possible options: {url}"
+                )
+
         strict = options.get("strict", False)
 
         follow_imports = options.get("follow-imports", "normal")
@@ -58,7 +77,7 @@ class MypyTool(ToolBase):
         strict_optional = options.get("strict-optional", False)
         namespace_packages = options.get("namespace-packages", False)
 
-        self.options.append("--follow-imports=%s" % follow_imports)
+        self.options.append(f"--follow-imports={follow_imports}")
 
         if strict:
             self.options.append("--strict")
@@ -70,13 +89,13 @@ class MypyTool(ToolBase):
             self.options.append("--implict-optional")
 
         if platform:
-            self.options.append("--platform %s" % platform)
+            self.options.append(f"--platform {platform}")
 
         if python_2_mode:
             self.options.append("--py2")
 
         if python_version:
-            self.options.append("--python-version %s" % python_version)
+            self.options.append(f"--python-version {python_version}")
 
         if strict_optional:
             self.options.append("--strict-optional")
@@ -84,12 +103,12 @@ class MypyTool(ToolBase):
         if namespace_packages:
             self.options.append("--namespace-packages")
 
-        for list_option in MYPY_OPTIONS:
+        for list_option in LIST_OPTIONS:
             for entry in options.get(list_option, []):
-                self.options.append("--%s-%s" % (list_option, entry))
+                self.options.append(f"--{list_option}-{entry}")
 
     def run(self, found_files):
-        paths = [path for path in found_files.iter_module_paths()]
+        paths = list(found_files.iter_module_paths())
         paths.extend(self.options)
         result = self.checker.run(paths)
         report, _ = result[0], result[1:]  # noqa
